translate.storage.tmdb

Package translate :: Package storage :: Module tmdb |
[hide private]
[frames] | no frames]

# Module tmdb

source code

Module to provide a translation memory database.

Classes | [hide private]
| LanguageError
| TMDB

Functions | [hide private]
min_levenshtein_length(length, min_similarity) | source code
max_levenshtein_length(length, min_similarity, max_length) | source code

Variables | [hide private]
| STRIP_REGEXP = `re.compile(r'`(?u)`\W')`

Imports: math, time, logging, re, threading, dbapi2, LevenshteinComparer, data